aboutsummaryrefslogtreecommitdiff
path: root/core/interrupts.c
diff options
context:
space:
mode:
authorVasant Hegde <hegdevasant@linux.vnet.ibm.com>2018-04-23 12:15:31 +0530
committerStewart Smith <stewart@linux.ibm.com>2018-04-30 19:04:42 -0500
commit6421fc56dc289c8d14a1ce9eddbb88d3687fbb77 (patch)
tree1e62f2f3795e0476f092107d76a68b1a432e7394 /core/interrupts.c
parent6739c890a2f298ed382b9557840a493fb97df44b (diff)
downloadskiboot-6421fc56dc289c8d14a1ce9eddbb88d3687fbb77.zip
skiboot-6421fc56dc289c8d14a1ce9eddbb88d3687fbb77.tar.gz
skiboot-6421fc56dc289c8d14a1ce9eddbb88d3687fbb77.tar.bz2
Move P8 timer code to separate file
Lets move P8 timer support code from slw.c to sbe-p8.c (as suggested by BenH). There is a difference between timer support in P8 and P9. Hence I think it makes sense to name it as sbe-p8.c. Note that this is pure code movement and renaming functions/variables. No functionality changes. Suggested-by: Benjamin Herrenschmidt <benh@kernel.crashing.org> Signed-off-by: Vasant Hegde <hegdevasant@linux.vnet.ibm.com> Signed-off-by: Stewart Smith <stewart@linux.ibm.com>
Diffstat (limited to 'core/interrupts.c')
-rw-r--r--core/interrupts.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/core/interrupts.c b/core/interrupts.c
index 50ff77a..4452511 100644
--- a/core/interrupts.c
+++ b/core/interrupts.c
@@ -25,6 +25,7 @@
#include <device.h>
#include <ccan/str/str.h>
#include <timer.h>
+#include <sbe-p8.h>
/* ICP registers */
#define ICP_XIRR 0x4 /* 32-bit access */
@@ -487,8 +488,8 @@ static int64_t opal_handle_interrupt(uint32_t isn, __be64 *outstanding_event_mas
/* Run it */
is->ops->interrupt(is, isn);
- /* Check timers if SLW timer isn't working */
- if (!slw_timer_ok())
+ /* Check timers if SBE timer isn't working */
+ if (!p8_sbe_timer_ok())
check_timers(true);
/* Update output events */